@@ -36,15 +36,14 @@ extract. <- function(.df, col, into, regex = "([[:alnum:]]+)",
 }
 
 #' @export
-extract..data.frame <- function(.df, col, into, regex = "([[:alnum:]]+)",
-                                remove = TRUE, convert = FALSE, ...) {
-  .df <- as_tidytable(.df)
+extract..tidytable <- function(.df, col, into, regex = "([[:alnum:]]+)",
+                               remove = TRUE, convert = FALSE, ...) {
   .df <- shallow(.df)
 
   if (missing(col)) abort("col is missing and must be supplied")
   if (missing(into)) abort("into is missing and must be supplied")
 
-  col <- select_vec_idx(.df, {{ col }})
+  col <- tidyselect_locs(.df, {{ col }})
 
   groups <- str_extract_groups(.df[[col]], regex, convert = convert)
 
@@ -72,6 +71,13 @@ extract..data.frame <- function(.df, col, into, regex = "([[:alnum:]]+)",
   .df[]
 }
 
+#' @export
+extract..data.frame <- function(.df, col, into, regex = "([[:alnum:]]+)",
+                                remove = TRUE, convert = FALSE, ...) {
+  .df <- as_tidytable(.df)
+  extract.(.df, {{ col }}, into, regex, remove, convert, ...)
+}
+
 str_extract_groups <- function(string, pattern, convert = FALSE){
   groups <- regexpr(pattern, string, perl = TRUE)
   start <- attr(groups, "capture.start")
