@@ -6,7 +6,7 @@
 #' @param .df A data.frame or data.table
 #' @param ... Columns to group and split by. `tidyselect` compatible.
 #' @param .keep Should the grouping columns be kept
-#' @param .named Should the list be named with labels that identify the group
+#' @param .named _experimental_: Should the list be named with labels that identify the group
 #'
 #' @export
 #'
@@ -16,7 +16,7 @@
 #'   b = 1:3,
 #'   c = c("a","a","b"),
 #'   d = c("a","a","b")
-#'  )
+#' )
 #'
 #' test_df %>%
 #'   group_split.(c, d)
@@ -31,9 +31,7 @@ group_split. <- function(.df, ..., .keep = TRUE, .named = FALSE) {
 }
 
 #' @export
-group_split..data.frame <- function(.df, ..., .keep = TRUE, .named = FALSE) {
-  .df <- as_tidytable(.df)
-
+group_split..tidytable <- function(.df, ..., .keep = TRUE, .named = FALSE) {
   vec_assert(.keep, logical(), 1)
   vec_assert(.named, logical(), 1)
 
@@ -42,11 +40,13 @@ group_split..data.frame <- function(.df, ..., .keep = TRUE, .named = FALSE) {
   if (length(dots) == 0) {
     list(.df)
   } else {
-    dots <- select_dots_chr(.df, ...)
+    by <- tidyselect_names(.df, !!!dots)
 
-    dots <- split(.df, by = dots, keep.by = .keep)
+    dots <- split(.df, by = by, keep.by = .keep)
 
-    if (!.named) {
+    if (.named) {
+      names(dots) <- str_replace_all.(names(dots), ".", "_", fixed = TRUE)
+    } else {
       dots <- unname(dots)
     }
 
@@ -54,3 +54,9 @@ group_split..data.frame <- function(.df, ..., .keep = TRUE, .named = FALSE) {
   }
 }
 
+#' @export
+group_split..data.frame <- function(.df, ..., .keep = TRUE, .named = FALSE) {
+  .df <- as_tidytable(.df)
+  group_split.(.df, ..., .keep = .keep, .named = .named)
+}
+
