@@ -57,12 +57,14 @@ mutate_across..data.frame <- function(.df, .cols = everything(), .fns = NULL, ..
 
   dots <- enquos(...)
 
+  dt_env <- build_dt_env(dots)
+
   .fns <- enexpr(.fns)
   if (is_null(.fns)) return(.df)
 
   call_list <- across_calls(.fns, .cols, .names, dots)
 
-  dt_expr <- call2("mutate.", .df, !!!call_list, .by = .by, .ns = "tidytable")
+  call_list <- as_quosures(call_list, dt_env)
 
-  eval_tidy(dt_expr, env = caller_env())
+  mutate.(.df, !!!call_list, .by = {{ .by }})
 }
