@@ -24,7 +24,6 @@
 #' @param ... Additional arguments to passed on to methods.
 #'
 #' @export
-#' @md
 #'
 #' @examples
 #' test_df <- data.table(
@@ -57,26 +56,24 @@ pivot_longer. <- function(.df,
 }
 
 #' @export
-pivot_longer..data.frame <- function(.df,
-                                     cols = everything(),
-                                     names_to = "name",
-                                     values_to = "value",
-                                     names_prefix = NULL,
-                                     names_sep = NULL,
-                                     names_pattern = NULL,
-                                     names_ptypes = list(),
-                                     names_transform = list(),
-                                     names_repair = "check_unique",
-                                     values_drop_na = FALSE,
-                                     values_ptypes = list(),
-                                     values_transform = list(),
-                                     fast_pivot = FALSE,
-                                     ...) {
-  .df <- as_tidytable(.df)
-
+pivot_longer..tidytable <- function(.df,
+                                    cols = everything(),
+                                    names_to = "name",
+                                    values_to = "value",
+                                    names_prefix = NULL,
+                                    names_sep = NULL,
+                                    names_pattern = NULL,
+                                    names_ptypes = list(),
+                                    names_transform = list(),
+                                    names_repair = "check_unique",
+                                    values_drop_na = FALSE,
+                                    values_ptypes = list(),
+                                    values_transform = list(),
+                                    fast_pivot = FALSE,
+                                    ...) {
   names <- names(.df)
 
-  measure_vars <- select_vec_chr(.df, {{ cols }})
+  measure_vars <- tidyselect_names(.df, {{ cols }})
 
   if (length(measure_vars) == 0) abort("At least one column must be supplied to cols")
 
@@ -216,6 +213,34 @@ pivot_longer..data.frame <- function(.df,
   as_tidytable(.df)
 }
 
+#' @export
+pivot_longer..data.frame <- function(.df,
+                                     cols = everything(),
+                                     names_to = "name",
+                                     values_to = "value",
+                                     names_prefix = NULL,
+                                     names_sep = NULL,
+                                     names_pattern = NULL,
+                                     names_ptypes = list(),
+                                     names_transform = list(),
+                                     names_repair = "check_unique",
+                                     values_drop_na = FALSE,
+                                     values_ptypes = list(),
+                                     values_transform = list(),
+                                     fast_pivot = FALSE,
+                                     ...) {
+  .df <- as_tidytable(.df)
+  pivot_longer.(
+    .df, cols = {{ cols }}, names_to = names_to,
+    values_to = values_to, names_prefix = names_prefix,
+    names_sep = names_sep, names_pattern = names_pattern,
+    names_ptypes = names_ptypes, names_transform = names_transform,
+    names_repair = names_repair, values_drop_na = values_drop_na,
+    values_ptypes = values_ptypes, values_transform = values_transform,
+    fast_pivot = fast_pivot
+  )
+}
+
 str_extract <- function(x, into, regex, convert = FALSE) {
   out <- str_extract_groups(x, pattern = regex, convert = convert)
   out <- as_tidytable(out)
