@@ -36,12 +36,11 @@ separate. <- function(.df, col, into,
 }
 
 #' @export
-separate..data.frame <- function(.df, col, into,
-                                 sep = "[^[:alnum:]]+",
-                                 remove = TRUE,
-                                 convert = FALSE,
-                                 ...) {
-  .df <- as_tidytable(.df)
+separate..tidytable <- function(.df, col, into,
+                                sep = "[^[:alnum:]]+",
+                                remove = TRUE,
+                                convert = FALSE,
+                                ...) {
   .df <- shallow(.df)
 
   vec_assert(into, character())
@@ -65,3 +64,16 @@ separate..data.frame <- function(.df, col, into,
 
   .df[]
 }
+
+#' @export
+separate..data.frame <- function(.df, col, into,
+                                 sep = "[^[:alnum:]]+",
+                                 remove = TRUE,
+                                 convert = FALSE,
+                                 ...) {
+  .df <- as_tidytable(.df)
+  separate.(
+    .df, col = {{ col }}, into = into, sep = sep,
+    remove = remove, convert = convert, ...
+  )
+}
