@@ -26,8 +26,7 @@ separate_rows. <- function(.df, ..., sep = "[^[:alnum:].]+", convert = FALSE) {
 }
 
 #' @export
-separate_rows..data.frame <- function(.df, ..., sep = "[^[:alnum:].]+", convert = FALSE) {
-  .df <- as_tidytable(.df)
+separate_rows..tidytable <- function(.df, ..., sep = "[^[:alnum:].]+", convert = FALSE) {
   .df <- shallow(.df)
 
   vec_assert(sep, character(), 1)
@@ -38,17 +37,20 @@ separate_rows..data.frame <- function(.df, ..., sep = "[^[:alnum:].]+", convert
   dots <- enquos(...)
   if (length(dots) == 0) return(.df)
 
-  mask <- build_data_mask(dots)
+  dt_env <- build_dt_env(dots)
 
-  cols <- select_dots_sym(.df, !!!dots)
+  cols <- tidyselect_syms(.df, !!!dots)
 
   .df[ , .id := .I]
 
   col_names <- as.character(cols)
   other_col_names <- setdiff(names(.df), col_names)
 
-  if (nchar(sep) == 1) fixed_flag <- TRUE
-  else fixed_flag <- FALSE
+  if (nchar(sep) == 1) {
+    fixed_flag <- TRUE
+  } else {
+    fixed_flag <- FALSE
+  }
 
   # Create a list of calls to strsplit()
   # Can't use a for loop - all columns selected must be in the same data.table call
@@ -61,7 +63,7 @@ separate_rows..data.frame <- function(.df, ..., sep = "[^[:alnum:].]+", convert
 
   dt_expr <- call2_j(.df, j, .by = other_col_names)
 
-  .df <- eval_tidy(dt_expr, mask, caller_env())
+  .df <- eval_tidy(dt_expr, env = dt_env)
 
   .df[ , .id := NULL]
 
@@ -72,4 +74,10 @@ separate_rows..data.frame <- function(.df, ..., sep = "[^[:alnum:].]+", convert
   .df[]
 }
 
+#' @export
+separate_rows..data.frame <- function(.df, ..., sep = "[^[:alnum:].]+", convert = FALSE) {
+  .df <- as_tidytable(.df)
+  separate_rows.(.df, ..., sep = sep, convert = convert)
+}
+
 globalVariables(".id")
