@@ -8,7 +8,6 @@
 #' @param wt Optional. The variable to use for ordering. If NULL uses the last column in the data.table.
 #' @param .by Columns to group by
 #'
-#' @md
 #' @export
 #'
 #' @examples
@@ -28,9 +27,7 @@ top_n. <- function(.df, n = 5, wt = NULL, .by = NULL) {
 }
 
 #' @export
-top_n..data.frame <- function(.df, n = 5, wt = NULL, .by = NULL) {
-  .df <- as_tidytable(.df)
-
+top_n..tidytable <- function(.df, n = 5, wt = NULL, .by = NULL) {
   wt <- enquo(wt)
 
   if (quo_is_null(wt)) {
@@ -39,3 +36,9 @@ top_n..data.frame <- function(.df, n = 5, wt = NULL, .by = NULL) {
     slice_max.(.df, order_by = !!wt, n = {{ n }}, .by = {{ .by }})
   }
 }
+
+#' @export
+top_n..data.frame <- function(.df, n = 5, wt = NULL, .by = NULL) {
+  .df <- as_tidytable(.df)
+  top_n.(.df, {{ n }}, {{ wt }}, .by = {{ .by }})
+}
