@@ -43,13 +43,11 @@ unnest. <- function(.df,
 }
 
 #' @export
-unnest..data.frame <- function(.df,
-                               ...,
-                               .drop = TRUE,
-                               names_sep = NULL,
-                               names_repair = "unique") {
-  .df <- as_tidytable(.df)
-
+unnest..tidytable <- function(.df,
+                              ...,
+                              .drop = TRUE,
+                              names_sep = NULL,
+                              names_repair = "unique") {
   vec_assert(.drop, logical(), 1)
 
   dots <- enquos(...)
@@ -61,7 +59,7 @@ unnest..data.frame <- function(.df,
   if (length(dots) == 0) {
     dots <- syms(data_names[list_flag])
   } else {
-    dots <- select_dots_sym(.df, ...)
+    dots <- tidyselect_syms(.df, ...)
   }
 
   keep_cols <- data_names[!list_flag]
@@ -96,6 +94,16 @@ unnest..data.frame <- function(.df,
   result_df
 }
 
+#' @export
+unnest..data.frame <- function(.df,
+                               ...,
+                               .drop = TRUE,
+                               names_sep = NULL,
+                               names_repair = "unique") {
+  .df <- as_tidytable(.df)
+  unnest.(.df, ..., .drop = .drop, names_sep = names_sep, names_repair = "unique")
+}
+
 unnest_col <- function(.df, col = NULL, names_sep = NULL) {
   # Check if nested data is a vector
   nested_data <- pull.(.df, !!col)[[1]]
