@@ -1,7 +1,6 @@
 test_df <- tidytable(a = c("a", "b", "a"), b = 3:1)
 
 test_that("ascending order works", {
-
   across_df <- arrange_across.(test_df)
 
   check_df <- arrange.(test_df, a, b)
@@ -11,10 +10,17 @@ test_that("ascending order works", {
 })
 
 test_that("descending order works", {
-
   across_df <- arrange_across.(test_df, everything(), desc.)
 
   check_df <- arrange.(test_df, -a, -b)
 
   expect_equal(across_df, check_df)
 })
+
+test_that("descending order works with rlang lambda", {
+  across_df <- arrange_across.(test_df, everything(), ~ desc.(.x))
+
+  check_df <- arrange.(test_df, -a, -b)
+
+  expect_equal(across_df, check_df)
+})
