@@ -71,16 +71,9 @@ test_that("preserves ordered factors", {
 test_that("preserves NAs", {
   x <- c(NA, "A", "B")
   expect_equal(crossing.(x)$x, x)
-  # expect_equal(nesting.(x)$x, x)
+  expect_equal(nesting.(x)$x, x)
 })
 
-# test_that("NULL inputs", {
-#   tb <- tidytable(x = 1:5)
-#   expect_equal(expand.(tb, x, y = NULL), tb)
-#   # expect_equal(nesting(x = tb$x, y = NULL), tb)
-#   expect_equal(crossing.(x = tb$x, y = NULL), tb)
-# })
-
 test_that("zero length input gives zero length output", {
   tb <- tidytable(x = character())
   expect_equal(expand.(tb, x), tb)
@@ -90,3 +83,25 @@ test_that("zero length input gives zero length output", {
     tidytable(x = integer(), y = integer())
   )
 })
+
+# nesting() ---------------------------------------------------
+test_that("nesting works", {
+  df <- tidytable(x = c(1, 1, 2), y = c(1, 1, 2))
+  out <- expand.(df, nesting.(x, y))
+  expect_equal(out$x, c(1, 2))
+  expect_equal(out$y, c(1, 2))
+})
+
+test_that("nesting doesn't expand values", {
+  df <- tidytable(x = 1:2, y = 1:2)
+  expect_equal(expand.(df, nesting.(x, y)), df)
+})
+
+test_that("unnamed data frames are flattened", {
+  df <- data.frame(x = 1:2, y = 1:2)
+  out <- expand.(df, nesting.(x, y))
+  expect_equal(out$x, df$x)
+
+  out <- crossing.(df)
+  expect_equal(out$x, df$x)
+})
